#
# spec file for package python-M2Crypto
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define oldpython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-M2Crypto
Version:        0.35.2
Release:        lp151.3.9.1
Summary:        Crypto and SSL toolkit for Python
License:        MIT
Group:          Development/Languages/Python
Url:            https://gitlab.com/m2crypto/m2crypto
Source:         https://files.pythonhosted.org/packages/source/M/M2Crypto/M2Crypto-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing}
BuildRequires:  fdupes
BuildRequires:  openssl
BuildRequires:  openssl-devel
BuildRequires:  python-rpm-macros
Requires:       python-typing
# hpj: SLES 12 and Leap 42.1 need swig3 to build this package
%if 0%{?sle_version} == 120100
BuildRequires:  swig3
%else
BuildRequires:  swig
%endif
%ifpython2
Provides:       %{oldpython}-m2crypto = %{version}
Obsoletes:      %{oldpython}-m2crypto < %{version}
%endif
%python_subpackages

%description
M2Crypto is a crypto and SSL toolkit for Python featuring the following:

RSA, DSA, DH, HMACs, message digests, symmetric ciphers (including
AES). SSL functionality to implement clients and servers. HTTPS
extensions to Python's httplib, urllib, and xmlrpclib. Unforgeable
HMAC'ing AuthCookies for web session management. FTP/TLS client and
server. S/MIME. ZServerSSL: A HTTPS server for Zope. ZSmime: An S/MIME
messenger for Zope.

%package -n %{name}-doc
Summary:        Documentation for the Crypto and SSL toolkit for Python
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
BuildArch:      noarch

%description -n %{name}-doc
M2Crypto is a crypto and SSL toolkit for Python featuring the following:

RSA, DSA, DH, HMACs, message digests, symmetric ciphers (including
AES). SSL functionality to implement clients and servers. HTTPS
extensions to Python's httplib, urllib, and xmlrpclib. Unforgeable
HMAC'ing AuthCookies for web session management. FTP/TLS client and
server. S/MIME. ZServerSSL: A HTTPS server for Zope. ZSmime: An S/MIME
messenger for Zope.

Documentation for the Crypto and SSL toolkit for Python

%prep
%setup -q -n M2Crypto-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%python_exec setup.py test

%files %{python_files}
%doc CHANGES LICENCE README.rst
%{python_sitearch}/*

%files -n %{name}-doc
%doc doc/*.rst

%changelog
* Thu May 28 2020 Julio González Gil <jgonzalez@suse.com>
- Add python3-M2crypto to LTSS channels, to allow using salt even
  when the Server Applications Module is not used (bsc#1172226)
* Wed Sep 18 2019 Matej Cepl <mcepl@suse.com>
- bsc#1149792 jsc#SLE-9135 Update to 0.35.2, bugfixes only.
  Changes cumulatively:
  - fix compatibility with OpenSSL 1.1.1c. Thank you,
    Sebastian Andrzej Siewior from the Debian team for resolving it.
  - Stop pretending to support Python 3.4.
  - The project is now Linux-distribution agnostic
  - Replace all old-style classes with the new ones (it shouldn't cause
    any problems, but feel free to file an issue, if it does)
  - Do not by-pass a potential transfer decoding in m2urllib2
  - SSLv3 just removed.
  - Various fixes of the build system and internal errors.
- Patch fix_urlunsplit.patch is removed, because it is included
  in the upstream tarball.
* Tue May 28 2019 Matej Cepl <mcepl@suse.com>
- Fix use of urlunsplit (bsc#1135009)
* Fri Feb  9 2018 michael@stroeder.com
- Update to 0.28.2:
  * Fix ppc builds
* Fri Feb  9 2018 tchvatal@suse.com
- Enable tests, fix docu install phase
* Thu Feb  8 2018 michael@stroeder.com
- Removed obsolete patches fix-build-python3.diff
  and fix-openssl-include-path.diff
- Update to 0.28.1
  * compability with Python 3
  * building on Mac OS X should be now more reliable and automagic
  * Fix licence in metadata: it is MIT, not BSD
  * Fix and add tests for SWIG/_aes.i module
  * Bundle-in unittest2 for Python 2.6
  * Remove all PGP modules
* Wed Nov  8 2017 jmatejek@suse.com
- use generic way to require python-typing now that python3 provides it
* Wed Oct 25 2017 michael@stroeder.com
- License set to MIT
* Fri Oct 20 2017 alarrosa@suse.com
- Remove unnecessary fdupes call
* Wed Oct 18 2017 alarrosa@suse.com
- Update to 0.27.0
  * Fix licence: it is MIT, not BSD
  * At least minimal support of SNI in httpslib.
  * Small bugfixes and cleanups.
  * More effort to make build system more robust.
  * Restore m2.rsa_set_e() and m2.rsa_set_n().
  * Make sure that every exceptional return throws and exception and viceversa.
- Add patch fix-build-python3.diff to let it build with python3
- Add patch fix-openssl-include-path.diff to fix openssl include path
  (the code already includes the openssl/ part)
- Create a new package python-M2Crypto-doc for documentation since rpmlint
  was complaining around 75%% of the package was documentation.
* Tue Sep 26 2017 michael@stroeder.com
- Update to 0.26.4 with fix for OpenSSL 1.1.0 and LibreSSL
* Fri Sep 22 2017 michael@stroeder.com
- Update to 0.26.3 with fix for a syntax error
* Thu Sep 21 2017 michael@stroeder.com
- Update to 0.26.2
  * compatibility with OpenSSL 1.1.0
* Mon Jun 19 2017 sebix+novell.com@sebix.at
- only require python3-typing if necessary
* Sat May  6 2017 toddrme2178@gmail.com
- It doesn't look like python3-m2crypto ever existed, so don't
  provide it.
* Thu Apr 27 2017 alarrosa@suse.com
- Add python-typing as a dependency
* Wed Apr 26 2017 alarrosa@suse.com
- Provide python-m2crypto in the python2 package
* Tue Apr 18 2017 toddrme2178@gmail.com
- Update to 0.26.0
  * No changelog provided
- Implement single-spec version.
* Mon Sep 12 2016 dmueller@suse.com
- use pypi.io as Source URL
* Fri Jul 22 2016 michael@stroeder.com
- update to 0.25.1
- set new dependency on package python-typing
* Fri Jun  3 2016 jweberhofer@weberhofer.at
- update to 0.24.0
  * No changelog provided
- README is no longer included
- Removed obsolete python-M2Crypto-SWIG-3.0.5.patch
* Mon Dec  7 2015 opensuse@dstoecker.de
- fix SSLv2 link error for 13.2 and Leap 42.1 (M2Crypto-0.22.5-SSLv2_link_error.patch)
* Sat Dec  5 2015 opensuse@dstoecker.de
- update to 0.22.5, fix URL
- drop python-M2Crypto-SWIG-3.0.5.patch (functionality included upstream)
* Thu Nov 26 2015 hpj@urpla.net
- SLE12 requires swig3 for a successful build, too
* Tue Nov 17 2015 hpj@urpla.net
- fix build for openSUSE Leap 42.1 (requires swig3)
* Tue Feb 24 2015 dimstar@opensuse.org
- Add python-M2Crypto-SWIG-3.0.5.patch: Fix generation of M2Crypto
  module when using SWIG 3.0.5.
- Manually install _m2crypto shadow file: setup.py misses it.
  (boo#917759, boo#917815).
* Thu Apr 17 2014 hrvoje.senjan@gmail.com
- Update to 0.22.3
  * No changelog provided
- Demos are no longer included
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Sep 13 2013 jmatejek@suse.com
- fixed %%fdupes creating dangling symlinks (bnc#835687)
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Jan 14 2013 saschpe@suse.de
- Add requirement on python-pyOpenSSL, thinner than M2Crypto
* Wed Oct 31 2012 saschpe@suse.de
- Narrow the scops of fdupes (see bnc#784670)
* Tue Jan 24 2012 bwiedemann@suse.com
- fix Obsoletes
* Tue Dec 13 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Sep 22 2011 saschpe@suse.de
- Use SPDX style license
- Require python-distribute instead of python-setuptools
- Don't package testsuite
* Tue May 31 2011 saschpe@suse.de
- Renamed to python-M2Crypto to match PyPI upstream name
  * Added Provides/Obsoletes for python-m2crypto
- Fixed wrong-EOL, executable bit for docs rpmlint warnings
* Mon Apr 18 2011 saschpe@suse.de
- Update to 0.21.1
  - Support OpenSSL 1.0. Thanks to Miloslav Trmac for figuring out
    how to fix test_smime.py
  - Rename m2.engine_init to engine_init_error so that ENGINE_init
    and ENGINE_finish can be exposed, thanks to Erlo
  - 0.20 started releasing Python locks even around some operations
    that interacted with the Python runtime, potentially causing
    crashes and other weirdness, fix by Miloslav Trmac
  - Make httpslib.ProxyHTTPSConnection work with Python 2.3
- Removed patches that are now upstream
- Removed authors from spec
* Tue Apr 20 2010 lnussel@suse.de
- add some upstream patches to fix openssl 1.0 build
* Tue Mar 30 2010 matejcik@suse.cz
- update to 0.20.2
  * PGP subpackage is deprecated
  * m2urllib now closes sockets properly
  * port is now integer in ProxyHTTPSConnection
  * many bugfixes
  * test coverage up to 80%%
- enabled test suite in %%check phase
  (requires python-setuptools and openssl binary to run)
* Fri Feb 27 2009 jblunck@suse.de
- Update to M2Crypto 0.19.1.
* Tue Jan 13 2009 matejcik@suse.cz
- package taken from devel:languages:python in OBS
